/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.guard.milter.osgi;

import com.openexchange.guard.configuration.GuardConfigurationService;
import com.openexchange.guard.keymanagement.services.RecipKeyService;
import com.openexchange.guard.milter.server.MilterServer;
import com.openexchange.guard.pgpcore.services.PGPCryptoService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link MilterActivator}
 *
 * @author <a href="greg.hill@open-xchange.com">Greg Hill</a>
 * @since 2.8.0
 */
public class MilterActivator extends HousekeepingActivator {


    private MilterServer server = null;
    /**
     * {@inheritDoc}
     */
    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { GuardConfigurationService.class, RecipKeyService.class };
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void startBundle() throws Exception {
        org.slf4j.LoggerFactory.getLogger(MilterActivator.class).info("Starting bundle: {}", context.getBundle().getSymbolicName());

        Services.setServiceLookup(this);
        server = new MilterServer();
        server.Startup();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected void stopBundle() throws Exception {
        org.slf4j.LoggerFactory.getLogger(MilterActivator.class).info("Stopping bundle: {}", this.context.getBundle().getSymbolicName());

        Services.setServiceLookup(null);
        server.stop();
        super.stopBundle();
    }
}

